@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -163,6 +171,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "CN", "چین" },
             { "CO", "کولمبیا" },
             { "CP", "د کلپرټون ټاپو" },
+            { "CQ", "سارک" },
             { "CR", "کوستاریکا" },
             { "CU", "کیوبا" },
             { "CV", "کیپ ورد" },
@@ -456,7 +465,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "ko", metaValue_ko },
             { "kr", "کنوری" },
             { "ks", "کشمیري" },
-            { "ku", "کردي" },
+            { "ku", "کرمانجي" },
             { "kv", "کومی" },
             { "kw", "کورنيشي" },
             { "ky", "کرغيزي" },
@@ -883,10 +892,13 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "key.cf", "اسعارو بڼه" },
             { "key.co", "ترتيب" },
             { "key.cu", "اسعارو" },
+            { "key.em", "ایموجي پریزنټیشن" },
             { "key.hc", "د ساعت چکر (۱۲ پرتله ۲۴)" },
             { "key.lb", "د ماتې کرښې ډول" },
+            { "key.lw", "د کلمو دننه د کرښې وقفې" },
             { "key.ms", "د ناپ نظام" },
             { "key.nu", "شمېرې" },
+            { "key.ss", "جملې وقفه د ابر څخه وروسته" },
             { "hi_Latn", "هندي (لاتيني)" },
             { "zh_Hant", "دوديزه چيني" },
             { "type.ca.roc", "منگوو جنتري" },
@@ -930,8 +942,8 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "type.ca.coptic", "کاپټیک کیلنډر" },
             { "type.ca.hebrew", "جورجویان جنتري" },
             { "type.co.search", "د عمومي موخي لټون" },
-            { "type.lb.normal", "د عادي ماتې کرښې ډول" },
-            { "type.lb.strict", "د سختې ماتې کرښې ډول" },
+            { "type.lb.normal", "د عادي کرښې ماتولو طرز" },
+            { "type.lb.strict", "د سختې کرښې ماتولو طرز" },
             { "type.ms.metric", "ميټرک نظام" },
             { "type.ca.chinese", "د چين جنتري" },
             { "type.ca.islamic", "اسلامي جنتري" },
